<?php

/*
 * LMS version 1.11.7 Bastet
 *
 *  (C) Copyright 2001-2009 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: strings.php,v 1.9 2009/01/13 07:45:29 alec Exp $
 */

$_LANG['All payments send on account:'] = 'Wszystkie płatności prosimy przesyłać na konto:';
$_LANG['Bank:'] = 'Bank:';
$_LANG['Customer Information:'] = 'Informacje o kliencie:';
$_LANG['Customer Logon'] = 'Panel Klienta';
$_LANG['Customer Logon: $0'] = 'Panel Klienta: $0';
$_LANG['Errornous data was entered!'] = 'Wprowadzono niepoprawne dane!';
$_LANG['Form Printout'] = 'Wydruk formularza';
$_LANG['home page'] = 'strona domowa';
$_LANG['Payments:'] = 'Płatności:';
$_LANG['Please to fill following form with customer ID and PIN which was sent to your email.'] = 'Proszę wypełnić formularz podając ID klienta oraz PIN, który był wysłany e-mailem.';
$_LANG['Print<BR>Payment<BR>Form'] = 'Wydruk<BR>Formularza<BR>Wpłaty';
$_LANG['We are please for punctual payment in value: <B>$0</B> with comment: $1'] = 'Prosimy o terminową wpłatę w wysokości: <B>$0</B> z dopiskiem: $1';
$_LANG['You have no outstandings towards as.'] = 'Nie posiadasz zaległości wobec nas.';
$_LANG['You have overpayments on value: $0, they will be moved as payments for future subscriptions or services.'] = 'Posiadasz nadpłaty w wysokości: $0, zostaną one rozliczone jako płatności za przyszły abonament lub usługę.';

?>